@@ -27,7 +27,8 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Dict, List, Optional, TypeVar, Union
 
 import _discord.abc
-from _discord.interactions import InteractionMessage
+from _discord.interactions import InteractionMessage, InteractionResponse, Interaction
+from _discord.webhook.async_ import Webhook
 
 if TYPE_CHECKING:
     from typing_extensions import ParamSpec
@@ -43,6 +44,7 @@ if TYPE_CHECKING:
     from ..member import Member
     from ..message import Message
     from ..user import User
+    from ..permissions import Permissions
     from ..client import ClientUser
     from _discord.webhook.async_ import Webhook
 
@@ -126,6 +128,7 @@ class ApplicationContext(_discord.abc.Messageable):
             The arguments to use.
         \*\*kwargs
             The keyword arguments to use.
+
         Raises
         -------
         TypeError
@@ -135,44 +138,62 @@ class ApplicationContext(_discord.abc.Messageable):
 
     @cached_property
     def channel(self) -> Optional[InteractionChannel]:
+        """Union[:class:`abc.GuildChannel`, :class:`PartialMessageable`, :class:`Thread`]:
+        Returns the channel associated with this context's command. Shorthand for :attr:`.Interaction.channel`."""
         return self.interaction.channel
 
     @cached_property
     def channel_id(self) -> Optional[int]:
+        """:class:`int`: Returns the ID of the channel associated with this context's command. Shorthand for :attr:`.Interaction.channel.id`."""
         return self.interaction.channel_id
 
     @cached_property
     def guild(self) -> Optional[Guild]:
+        """Optional[:class:`.Guild`]: Returns the guild associated with this context's command. Shorthand for :attr:`.Interaction.guild`."""
         return self.interaction.guild
 
     @cached_property
     def guild_id(self) -> Optional[int]:
+        """:class:`int`: Returns the ID of the guild associated with this context's command. Shorthand for :attr:`.Interaction.guild.id`."""
         return self.interaction.guild_id
 
     @cached_property
     def locale(self) -> Optional[str]:
+        """:class:`str`: Returns the locale of the guild associated with this context's command. Shorthand for :attr:`.Interaction.locale`."""
         return self.interaction.locale
 
     @cached_property
     def guild_locale(self) -> Optional[str]:
+        """:class:`str`: Returns the locale of the guild associated with this context's command. Shorthand for :attr:`.Interaction.guild_locale`."""
         return self.interaction.guild_locale
 
+    @cached_property
+    def app_permissions(self) -> Permissions:
+        return self.interaction.app_permissions
+
     @cached_property
     def me(self) -> Optional[Union[Member, ClientUser]]:
+        """Union[:class:`.Member`, :class:`.ClientUser`]:
+        Similar to :attr:`.Guild.me` except it may return the :class:`.ClientUser` in private message
+        message contexts, or when :meth:`Intents.guilds` is absent.
+        """
         return self.interaction.guild.me if self.interaction.guild is not None else self.bot.user
 
     @cached_property
     def message(self) -> Optional[Message]:
+        """Optional[:class:`.Message`]: Returns the message sent with this context's command. Shorthand for :attr:`.Interaction.message`, if applicable."""
         return self.interaction.message
 
     @cached_property
     def user(self) -> Optional[Union[Member, User]]:
+        """Union[:class:`.Member`, :class:`.User`]: Returns the user that sent this context's command. Shorthand for :attr:`.Interaction.user`."""
         return self.interaction.user
 
     author: Optional[Union[Member, User]] = user
 
     @property
     def voice_client(self) -> Optional[VoiceProtocol]:
+        """Optional[:class:`.VoiceProtocol`]: Returns the voice client associated with this context's command. Shorthand for :attr:`.Interaction.guild.voice_client`, if applicable."""
         if self.interaction.guild is None:
             return None
 
@@ -180,6 +201,7 @@ class ApplicationContext(_discord.abc.Messageable):
 
     @cached_property
     def response(self) -> InteractionResponse:
+        """:class:`.InteractionResponse`: Returns the response object associated with this context's command. Shorthand for :attr:`.Interaction.response`."""
         return self.interaction.response
 
     @property
@@ -216,20 +238,31 @@ class ApplicationContext(_discord.abc.Messageable):
         return None
 
     @property
+    @_discord.utils.copy_doc(InteractionResponse.send_modal)
     def send_modal(self) -> Callable[..., Awaitable[Interaction]]:
-        """Sends a modal dialog to the user who invoked the interaction."""
         return self.interaction.response.send_modal
 
-    @property
-    def respond(self) -> Callable[..., Awaitable[Union[Interaction, WebhookMessage]]]:
-        """Callable[..., Union[:class:`~.Interaction`, :class:`~.Webhook`]]: Sends either a response
-        or a followup response depending on if the interaction has been responded to yet or not."""
-        if not self.interaction.response.is_done():
-            return self.interaction.response.send_message  # self.response
-        else:
-            return self.followup.send  # self.send_followup
+    async def respond(self, *args, **kwargs) -> Union[Interaction, WebhookMessage]:
+        """|coro|
+
+        Sends either a response or a message using the followup webhook depending determined by whether the interaction
+        has been responded to or not.
+
+        Returns
+        -------
+        Union[:class:`discord.Interaction`, :class:`discord.WebhookMessage`]:
+            The response, its type depending on whether it's an interaction response or a followup.
+        """
+        try:
+            if not self.interaction.response.is_done():
+                return await self.interaction.response.send_message(*args, **kwargs)  # self.response
+            else:
+                return await self.followup.send(*args, **kwargs)  # self.send_followup
+        except _discord.errors.InteractionResponded:
+            return await self.followup.send(*args, **kwargs)
 
     @property
+    @_discord.utils.copy_doc(InteractionResponse.send_message)
     def send_response(self) -> Callable[..., Awaitable[Interaction]]:
         if not self.interaction.response.is_done():
             return self.interaction.response.send_message
@@ -239,6 +272,7 @@ class ApplicationContext(_discord.abc.Messageable):
             )
 
     @property
+    @_discord.utils.copy_doc(Webhook.send)
     def send_followup(self) -> Callable[..., Awaitable[WebhookMessage]]:
         if self.interaction.response.is_done():
             return self.followup.send
@@ -248,22 +282,41 @@ class ApplicationContext(_discord.abc.Messageable):
             )
 
     @property
+    @_discord.utils.copy_doc(InteractionResponse.defer)
     def defer(self) -> Callable[..., Awaitable[None]]:
         return self.interaction.response.defer
 
     @property
     def followup(self) -> Webhook:
+        """:class:`Webhook`: Returns the follow up webhook for follow up interactions."""
         return self.interaction.followup
 
-    async def delete(self):
-        """Calls :attr:`~discord.commands.ApplicationContext.respond`.
-        If the response is done, then calls :attr:`~discord.commands.ApplicationContext.respond` first."""
+    async def delete(self, *, delay: Optional[float] = None) -> None:
+        """|coro|
+
+        Deletes the original interaction response message.
+
+        This is a higher level interface to :meth:`Interaction.delete_original_message`.
+
+        Parameters
+        -----------
+        delay: Optional[:class:`float`]
+            If provided, the number of seconds to wait before deleting the message.
+
+        Raises
+        -------
+        HTTPException
+            Deleting the message failed.
+        Forbidden
+            You do not have proper permissions to delete the message.
+        """
         if not self.interaction.response.is_done():
             await self.defer()
 
-        return await self.interaction.delete_original_message()
+        return await self.interaction.delete_original_message(delay=delay)
 
     @property
+    @_discord.utils.copy_doc(Interaction.edit_original_message)
     def edit(self) -> Callable[..., Awaitable[InteractionMessage]]:
         return self.interaction.edit_original_message
 
